@@ -1396,6 +1396,11 @@ class WorkingSite(Site):
     clear_queue = flow.Child(ClearQueueAction)
     site_environment = flow.Child(SiteEnvironment)
 
+    with flow.group('AfterEffects settings'):
+        ae_render_settings     = flow.Param().ui(label='Render settings')
+        ae_output_module_movie = flow.Param().ui(label='Output module (movie)')
+        ae_output_module_audio = flow.Param().ui(label='Output module (audio)')
+
     def compute_child_value(self, child_value):
         if child_value is self.root_folder:
             root_dir = None
@@ -1464,8 +1469,13 @@ class ClearSiteQueues(flow.Action):
         
         for s in self._sites.mapped_items():
             for j in s.get_jobs(status='PROCESSED'):
-                if time.time() - j.date.get() > self.emitted_since.get():
-                    s.queue.job_list.remove(j.name())
+                c = s.queue.job_list.get_entity_store().get_collection(
+                    s.queue.job_list.collection_name()
+                )
+                c.delete_many({
+                    'date': {'$lt': time.time() - self.emitted_since.get()},
+                    'status': 'PROCESSED'
+                })
 
         self.root().project().synchronization.touch()
 
@@ -1478,7 +1488,7 @@ class WorkingSites(SiteMap):
 
     @classmethod
     def mapped_type(cls):
-        return WorkingSite
+        return flow.injection.injectable(WorkingSite)
 
     def _configure_child(self, child):
         if child.name() == "default":
