@@ -14,14 +14,20 @@ from libreflow import resources
 
 
 class ProjectThumbnailWidget(QtWidgets.QAbstractButton):
-    def __init__(self, width, height, image_path=None, alt_text="", parent=None):
+    def __init__(self, width, height, image_path=None, alt_text="", parent=None, image=None):
         super(ProjectThumbnailWidget, self).__init__(parent)
         self.setThumnail = True
         self.alt_text = alt_text
-        if image_path is None:
-            self.setThumnail = False
-        else:
+        if image:
+            ba = QtCore.QByteArray.fromBase64(bytes(image.split(',')[1], "utf-8"))
+            pixmap = QtGui.QPixmap()
+            pixmap.loadFromData(ba, "PNG")
+            self.thumbnail = pixmap
+        elif image_path:
+            print("loading thumbnail from path")
             self.thumbnail = QtGui.QPixmap(image_path)
+        else:
+            self.setThumnail = False
 
         self.width = width
         self.height = height
@@ -63,10 +69,23 @@ class ProjectWidget(QtWidgets.QWidget):
             )
         except AttributeError:
             project_thumbnail_path = None
-
-        self.thumbnail_button = ProjectThumbnailWidget(
-            600, 150, image_path=project_thumbnail_path, alt_text=project
-        )
+        
+        try:    
+            project_thumbnail = self.HomePageWidget.session.cmds.Flow.call(
+                "/%s" % project, "get_project_thumbnail2", {}, {}
+                )
+            
+        except AttributeError:
+            project_thumbnail = None
+        
+        if project_thumbnail:
+            self.thumbnail_button = ProjectThumbnailWidget(
+                600, 150, image_path=None, alt_text=project, image=project_thumbnail
+            )
+        else:
+            self.thumbnail_button = ProjectThumbnailWidget(
+                600, 150, image_path=project_thumbnail_path, alt_text=project
+            )
 
         custom_home_star_path = os.path.join(
             os.path.dirname(resources.icons.libreflow.__file__), "custom_home_star.png"
@@ -98,7 +117,7 @@ class ProjectWidget(QtWidgets.QWidget):
         if button == "thumbnail":
             oid = "/%s" % project
         elif button == "fav":
-            oid = "/%s/admin/bookmarks" % project
+            oid = "/%s/user" % project
         self.HomePageWidget.page.goto(oid)
 
 
