@@ -5,6 +5,7 @@ import argparse
 
 from kabaret.app.session import KabaretSession
 from kabaret.app.actors.flow import Flow
+from kabaret import flow
 
 
 class CleanSyncJobsSession(KabaretSession):
@@ -15,6 +16,15 @@ class CleanSyncJobsSession(KabaretSession):
     def clear_jobs(self, project_name, clear_every=900, clear_before=1800):
         clear_action_oid = f'/{project_name}/admin/multisites/working_sites/clear_site_queues'
 
+        try:
+            valid_project = self.cmds.Flow.is_action(clear_action_oid)
+        except (flow.MissingChildError, flow.MissingRelationError):
+            valid_project = False
+        
+        if not valid_project:
+            self.log_error('Invalid project !')
+            return
+
         try:
             while True:
                 self.log_info('Clearing jobs (%s)...' % datetime.datetime.fromtimestamp(time.time()))
@@ -79,13 +89,6 @@ def main(argv):
     # Check project root type
     project_type_name = session.get_actor('Flow').get_project_qualified_type_name(project_name)
 
-    if project_type_name != 'libreflow.thesiren.flow.Project':
-        session.log_error(
-            f'Project root must be of type {project_type_name}, which this session is configured for.' \
-            'Please specify a project with the valid root type.'
-        )
-        return
-
     session.clear_jobs(project_name, clear_every=period, clear_before=time)
 
 
